/*
  Copyright (C) 2001 Jesper Hansen <jesperh@telia.com>.

  Rewritten by:	Nikolai Vorontsov <nickviz@mail.be>

  This file is part of the yampp system.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software Foundation, 
  Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef __REC80_H__
#define __REC80_H__

#include "Constants.h"
#include "types.h"


#define IR_PORT		PORTD
#define IR_BIT		PD2

bool rec80_active(void);

void init_rec80(void);
u16 get_rec80(void);


#ifdef REC80		// REC-80 codes
#define IR_PLAY		0x4e50
#define IR_STOP		0x1e00
#define IR_PAUSE	0x7e60
#define IR_PREV		0x5e40
#define IR_NEXT		0xdec0
#define IR_VOLUP	0x5846	/* zoom_T */	
#define IR_VOLDN	0xd8c6	/* zoom_W */
#define IR_RESET	0x342A
#define IR_NEXT10	0x4c52
#define IR_PREV10	0x8c92
#define IR_RANDOM	0xf4ea
#define IR_NEXTL	0xeef0
#define IR_PREVL	0xfee0
#endif

#ifdef NEC80		// NEC-80 codes
#define IR_PLAY		0x35fd
#define IR_STOP		0x35fc
#define IR_PAUSE	0x35fe
#define IR_PREV		0x35fa
#define IR_NEXT		0x35f8
#define IR_VOLUP	0x35ef
#define IR_VOLDN	0x35eb
#define IR_NEXT10	0x35e8
#define IR_PREV10	0x35ea
#define IR_RESET	0xffff
#define IR_RANDOM	0xffff
#define IR_NEXTL	0xffff
#define IR_PREVL	0xffff
#endif

#ifdef PANASONIC
#define IR_PLAY		0x0550
#define IR_STOP		0x5500
#define IR_PAUSE	0x3560
#define IR_PREV		0xc792
#define IR_NEXT		0x0752
#define IR_VOLUP	0x0104
#define IR_VOLDN	0x8184
#define IR_NEXT10	0x0451	/* Program */
#define IR_PREV10	0x90c5  /* Cancel */ 
#define IR_RESET	0x81bc  /* Power */
#define IR_RANDOM	0x88dd	/* PlayMode */
#define IR_NEXTL	0x4144	/* Bass + */
#define IR_PREVL	0xc1c4	/* Bass - */
// 0x81bc	/* Power */
// 0x5469	/* Sleep */
// 0x5c59	/* Aux */
// 0xd580	/* Open/Close */
// 0x3508	/* 1 */
// 0xb588	/* 2 */
// 0x7548	/* 3 */
// 0xd4e9	/* Dimmer */
// 0xf5c8	/* 4 */
// 0x1528	/* 5 */
// 0x95a8	/* 6 */
// 0x1c21	/* >=10 */
// 0x5568	/* 7 */
// 0xd5e8	/* 8 */
// 0x2518	/* 9 */
// 0xa598	/* 0 */
// 0x0451	/* Programm */
// 0x88dd	/* PlayMode */
// 0xc792	/* |<< */
// 0x0752	/* >>| */
// 0x90c5	/* Cancel */
// 0x5500	/* Stop */
// 0x3560	/* Pause */
// 0x0550	/* Play */
// 0x494c	/* Muting */
// 0x090c	/* Sound Virtualizer */
// 0xe9cc	/* Tuner FM mode */
// 0x0025	/* Tuner band */
// 0xc1c4	/* Bass - */
// 0x4144	/* Bass + */
// 0xa1a4	/* Treble - */
// 0x2124	/* Treble + */
// 0x8184	/* Volume - */
// 0x0104	/* Volume + */

#endif // PANASONIC


#ifdef CREATIVE_RM900
#define IR_PLAY		0x2286	/* Play/Pause */
#define IR_STOP		0x227a	/* Stop */
#define IR_PAUSE	0x2281	/* Slow */
#define IR_PREV		0x2280	/* Previous */
#define IR_NEXT		0x2285	/* Next */
#define IR_VOLUP	0x229d	/* Volume + */
#define IR_VOLDN	0x229c	/* Volume - */
#define IR_NEXT10	0x228a	/* Right Arrows */
#define IR_PREV10	0x2278	/* Left Arrows */
#define IR_RESET	0x2283	/* Close */
#define IR_RANDOM	0x2271	/* Return */
#define IR_NEXTL	0x2272	/* Down Arrow */
#define IR_PREVL	0x2284	/* Up Arrow */


// 0x2274	/* 1 */
// 0x2270	/* 2 */
// 0x226f	/* 3 */
// 0x2275	/* 4 */
// 0x227b 	/* 5 */
// 0x2287	/* 6 */
// 0x2276	/* 7 */
// 0x227c	/* 8 */
// 0x2288	/* 9 */
// 0x227f	/* 0 */
// 0x227a	/* Stop */
// 0x2286	/* Play/Pause */
// 0x2282	/* Step Forward */
// 0x2280	/* Previous */
// 0x2285	/* Next */
// 0x2281	/* Slow */
// 0x2291	/* Mute */
// 0x229c	/* Volume - */
// 0x229d	/* Volume + */
//   ? 		/* Speaker */
// 0x2273	/* EAX */
// 0x227d	/* Options */
// 0x2289	/* Display */
// 0x2271	/* Return */
// 0x2277	/* Start */
// 0x2283	/* Close */
// 0x2284	/* Up-arrow */
// 0x2278	/* Left Arrows */
// 0x227e	/* Select */
// 0x228a	/* Right Arrows */
// 0x2272	/* Down Arrow */

#endif	// CREATIVE_RM900


#endif // __REC80_H__
